@@ -6,8 +6,8 @@ import itertools
 from ndex2.nice_cx_network import NiceCXNetwork
 from collections import OrderedDict
 from indra.statements import *
-from indra.databases import context_client, ndex_client, get_identifiers_url, \
-    url_prefixes
+from indra.databases import context_client, ndex_client
+from indra.databases.identifiers import get_identifiers_url, url_prefixes
 
 
 logger = logging.getLogger(__name__)
@@ -35,6 +35,10 @@ class NiceCxAssembler(object):
                                            (network_name if network_name
                                             else 'indra_assembled'))
         self.node_keys = {}
+        self.context_prefixes = {
+            'pubmed': 'https://identifiers.org/pubmed:',
+            'hgnc.symbol': 'https://identifiers.org/hgnc.symbol:'
+        }
 
     def make_model(self, self_loops=False, network_attributes=None):
         """Return a Nice CX network object after running assembly.
@@ -64,9 +68,8 @@ class NiceCxAssembler(object):
                     continue
                 edge_id = self.add_edge(a1_id, a2_id, stmt)
 
-        prefixes = {k: v for k, v in url_prefixes.items()}
-        prefixes['pubmed'] = 'https://identifiers.org/pubmed/'
-        self.network.set_network_attribute('@context', json.dumps(prefixes))
+        self.network.set_network_attribute('@context',
+                                           json.dumps(self.context_prefixes))
         if network_attributes:
             for k, v in network_attributes.items():
                 self.network.set_network_attribute(k, v, 'string')
@@ -129,7 +132,7 @@ class NiceCxAssembler(object):
                 ev_txt = ev.text
             # Construct a clickable PMID link with the source and evidence text
             ev_str = ('<a target="_blank" '
-                      'href="http://identifiers.org/pubmed/%s'
+                      'href="https://identifiers.org/pubmed:%s">'
                       'pubmed:%s</a> (%s) %s') % (ev.pmid, ev.pmid,
                                                   ev.source_api, ev_txt)
             evs.append((ev_str, 0 if ev.text is None else 1))
@@ -530,7 +533,7 @@ class CxAssembler(object):
         edge = {'@id': edge_id,
                 's': source,
                 't': target,
-                'i': interaction}
+                'i': interaction.lower()}
         self.cx['edges'].append(edge)
         self._add_edge_metadata(edge_id, stmt)
         return edge_id
@@ -624,8 +627,10 @@ class CxAssembler(object):
 
 
 def _get_support_type(stmt):
-    dbs = ['bel', 'biopax', 'phosphosite', 'biogrid']
-    readers = ['reach', 'trips', 'sparser', 'r3']
+    dbs = ['bel', 'biopax', 'phosphosite', 'biogrid', 'signor', 'tas', 'hprd',
+           'trrust', 'ctd', 'virhostnet', 'phosphoelm', 'drugbank', 'omnipath']
+    readers = ['reach', 'trips', 'sparser', 'r3', 'eidos', 'geneways', 'tees',
+               'rlimsp', 'medscan']
     has_db = False
     has_reading = False
     for ev in stmt.evidence:
