@@ -52,7 +52,3 @@ def get_doid_id_from_doid_alt_id(doid_alt_id):
         The Disease Ontology identifier corresponding to the given alt id.
     """
     return _client.get_id_from_alt_id(doid_alt_id)
-
-
-if __name__ == '__main__':
-    print(*_client.count_xrefs().most_common(), sep='\n')
