@@ -1,4 +1,4 @@
-from .model_checker import ModelChecker, PathResult, PathMetric
+from .model_checker import ModelChecker, PathResult, PathMetric, NodesContainer
 from .pysb import PysbModelChecker
 from .signed_graph import SignedGraphModelChecker
 from .unsigned_graph import UnsignedGraphModelChecker
