@@ -1,7 +1,9 @@
 import logging
 import networkx as nx
-from . import ModelChecker
+from . import ModelChecker, NodesContainer
 from indra.statements import *
+from indra.ontology.bio import bio_ontology
+from indra.explanation.pathfinding.util import get_subgraph
 
 
 logger = logging.getLogger(__name__)
@@ -34,16 +36,36 @@ class UnsignedGraphModelChecker(ModelChecker):
                  nodes_to_agents=None):
         super().__init__(model, statements, do_sampling, seed, nodes_to_agents)
 
-    def get_graph(self):
+    def get_graph(self, edge_filter_func=None, copy_edge_data=None):
+        """Get a signed nodes graph to search for paths in.
+
+        Parameters
+        ----------
+        edge_filter_func : Optional[function]
+            A function to filter out edges from the graph. A function should
+            take nodes (and key in case of MultiGraph) as parameters and
+            return True if an edge can be in the graph and False if it should
+            be filtered out.
+        copy_edge_data : set(str)
+            A set of keys to copy from original model edge data to the graph
+            edge data. If None, only belief data is copied by default.
+        """
         if self.graph:
             return self.graph
+        if edge_filter_func:
+            filtered_model = get_subgraph(self.model, edge_filter_func)
+        else:
+            filtered_model = self.model
         self.graph = nx.DiGraph()
         nodes = []
-        for node, node_data in self.model.nodes(data=True):
+        for node, node_data in filtered_model.nodes(data=True):
             nodes.append(((node, 0), node_data))
         self.graph.add_nodes_from(nodes)
-        for (u, v, data) in self.model.edges(data=True):
-            self.graph.add_edge((u, 0), (v, 0), belief=data['belief'])
+        if not copy_edge_data:
+            copy_edge_data = {'belief'}
+        for (u, v, data) in filtered_model.edges(data=True):
+            edge_data = {k: data[k] for k in copy_edge_data}
+            self.graph.add_edge((u, 0), (v, 0), **edge_data)
         self.get_nodes_to_agents()
         return self.graph
 
@@ -55,22 +77,14 @@ class UnsignedGraphModelChecker(ModelChecker):
                         stmt.__class__.__name__)
             return (None, None, 'STATEMENT_TYPE_NOT_HANDLED')
         subj, obj = stmt.agent_list()
-        if obj is None:
-            obj_nodes = [None]
-        else:
-            obj_nodes = self.get_nodes(obj, self.graph)
-            # Statement has object but it's not in the graph
-            if not obj_nodes:
-                return (None, None, 'OBJECT_NOT_FOUND')
-        return ([subj], obj_nodes, None)
-
-    def process_subject(self, subj):
-        # We will not get here if subject is None
         subj_nodes = self.get_nodes(subj, self.graph)
-        # Statement has subject but it's not in the graph
-        if not subj_nodes:
-            return (None, 'SUBJECT_NOT_FOUND')
-        return subj_nodes, None
+        obj_nodes = self.get_nodes(obj, self.graph)
+        # Statement has object but it's not in the graph
+        if obj and not obj_nodes.all_nodes:
+            return (None, None, 'OBJECT_NOT_FOUND')
+        if subj and not subj_nodes.all_nodes:
+            return (None, None, 'SUBJECT_NOT_FOUND')
+        return (subj_nodes, obj_nodes, None)
 
     def _sample_paths(self, input_set, obj_name, target_polarity,
                       max_paths=1, max_path_length=5):
@@ -78,10 +92,22 @@ class UnsignedGraphModelChecker(ModelChecker):
         pass
 
     def get_nodes(self, agent, graph):
+        """Get all nodes corresponding to a given agent."""
+        nc = NodesContainer(agent)
+        if agent is None:
+            nc.all_nodes = None
+            return nc
         node = (agent.name, 0)
-        if node not in graph.nodes:
-            return None
-        return [node]
+        if node in graph.nodes:
+            nc.main_nodes.append(node)
+        for n, ag in self.nodes_to_agents.items():
+            if ag is not None and not ag.matches(agent) and ag.refinement_of(
+                    agent, bio_ontology):
+                node = (n, 0)
+                if node in graph.nodes:
+                    nc.ref_nodes.append(node)
+        nc.get_all_nodes()
+        return nc
 
     def get_nodes_to_agents(self):
         """Return a dictionary mapping IndraNet nodes to INDRA agents."""
