@@ -19,10 +19,13 @@ class BioOntology(IndraOntology):
     # should be incremented to "force" rebuilding the ontology to be consistent
     # with the underlying resource files.
     name = 'bio'
-    version = '1.18'
+    version = '1.27'
+    ontology_namespaces = [
+        'go', 'efo', 'hp', 'doid', 'chebi', 'ido', 'mondo', 'eccode',
+    ]
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def initialize(self, rebuild=False):
         if rebuild or not os.path.exists(CACHE_FILE):
@@ -72,6 +75,7 @@ class BioOntology(IndraOntology):
         self.add_mesh_xrefs()
         self.add_mirbase_xrefs()
         self.add_hms_lincs_xrefs()
+        self.add_pubchem_xrefs()
         self.add_biomappings()
         # Add hierarchies
         logger.info('Adding hierarchy...')
@@ -82,6 +86,10 @@ class BioOntology(IndraOntology):
         self.add_modification_hierarchy()
         self.add_uppro_hierarchy()
         self.add_lspci()
+        # Add replacements
+        logger.info('Adding replacements...')
+        self.add_uniprot_replacements()
+        self.add_obo_replacements()
 
         # The graph is now initialized
         self._initialized = True
@@ -107,6 +115,8 @@ class BioOntology(IndraOntology):
                    'type': _get_uniprot_type(uniprot_client, uid)})
                  for (uid, uname)
                  in uniprot_client.um.uniprot_gene_name.items()]
+        for sec_id in uniprot_client.um.uniprot_sec:
+            nodes.append((self.label('UP', sec_id), {'obsolete': True}))
         self.add_nodes_from(nodes)
 
     def add_uppro_nodes(self):
@@ -202,7 +212,6 @@ class BioOntology(IndraOntology):
 
     def add_obo_nodes(self):
         from indra.databases import obo_client
-        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi', 'ido']
         nodes = []
         type_functions = {
             'go': _get_go_type,
@@ -210,9 +219,11 @@ class BioOntology(IndraOntology):
             'hp': lambda x: 'disease',
             'doid': lambda x: 'disease',
             'chebi': lambda x: 'small_molecule',
-            'ido': lambda x: 'infectious_disease_concept'
+            'ido': lambda x: 'infectious_disease_concept',
+            'mondo': lambda x: 'disease',
+            'eccode': lambda x: 'molecular_function',
         }
-        for ns in namespaces:
+        for ns in self.ontology_namespaces:
             oc = obo_client.OntologyClient(prefix=ns)
             for db_id, entry in oc.entries.items():
                 label = self.label(ns.upper(), db_id)
@@ -225,11 +236,28 @@ class BioOntology(IndraOntology):
                 nodes.append((label,
                               {'name': entry['name'],
                                'type': type_functions[ns](db_id)}))
+            # Add nodes for secondary IDs as obsolete
+            for alt_id in oc.alt_to_id:
+                if alt_id.startswith(ns.upper()):
+                    nodes.append((self.label(ns.upper(), alt_id),
+                                  {'obsolete': True}))
         self.add_nodes_from(nodes)
 
+    def add_obo_replacements(self):
+        from indra.databases import obo_client
+        edges = []
+        for ns in self.ontology_namespaces:
+            oc = obo_client.OntologyClient(prefix=ns)
+            for alt_id, prim_id in oc.alt_to_id.items():
+                if alt_id.startswith(ns.upper()) and \
+                        prim_id.startswith(ns.upper()):
+                    edges.append((self.label(ns.upper(), alt_id),
+                                 self.label(ns.upper(), prim_id),
+                                 {'type': 'replaced_by'}))
+        self.add_edges_from(edges)
+
     def add_obo_hierarchies(self):
         from indra.databases import obo_client
-        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi', 'ido']
         edges = []
         # Mapping various source relation types to standardized ones
         # in this ontology graph
@@ -250,10 +278,34 @@ class BioOntology(IndraOntology):
         reverse_rel = {
             'has_part',
         }
-        for ns in namespaces:
+
+        exceptions = {
+            # Some (non-physical entity) GO terms have a has_part relationship
+            # that creates cycles in the isa/partof subgraph. One example is
+            # signaling receptor binding (GO:GO:0005102)-[partof]-
+            #      pheromone activity (GO:GO:0005186)
+            # where the first is actually a more generic term compared to the
+            # second. The semantics of these are different from typical partof
+            # relations in INDRA so we exclude them.
+            'GO': ('has_part', lambda x: x['type'] != 'cellular_component'),
+            # Similarly, CHEBI partof/isa relations have cycles, for example,
+            # molybdate (CHEBI:CHEBI:36264)-[partof]-
+            #     sodium molybdate (anhydrous) (CHEBI:CHEBI:75215)
+            # sodium molybdate (anhydrous) (CHEBI:CHEBI:75215)-[partof]-
+            #     sodium molybdate tetrahydrate (CHEBI:CHEBI:132099)
+            # sodium molybdate tetrahydrate (CHEBI:CHEBI:132099)-[isa]-
+            #     molybdate (CHEBI:CHEBI:36264)
+            # For simplicity, we exclude all has_part (i.e., reverse partof)
+            # relations coming from CHEBI.
+            'CHEBI': ('has_part', lambda x: True),
+        }
+
+        for ns in self.ontology_namespaces:
             oc = obo_client.OntologyClient(prefix=ns)
+            ns_exceptions = exceptions.get(ns.upper())
             for db_id, entry in oc.entries.items():
                 for rel, targets in entry.get('relations', {}).items():
+
                     # Skip unknown relation types
                     mapped_rel = rel_mappings.get(rel)
                     if not mapped_rel:
@@ -262,6 +314,13 @@ class BioOntology(IndraOntology):
                         source_label = db_id
                     else:
                         source_label = self.label(ns.upper(), db_id)
+
+                    # Here we check if there is an exception condition defined
+                    # on the inclusion of these relations
+                    if ns_exceptions and rel == ns_exceptions[0]:
+                        if ns_exceptions[1](self.nodes[source_label]):
+                            continue
+
                     for target in targets:
                         if ':' in target and not target.startswith(ns.upper()):
                             target_label = target
@@ -364,6 +423,12 @@ class BioOntology(IndraOntology):
                 edges.append((self.label('MESH', mesh_id),
                               self.label('MESH', parent_id),
                               {'type': 'isa'}))
+        # Handle any replacements
+        replacements = [('C000657245', 'D000086382')]
+        for mesh_id, replacement_id in replacements:
+            edges.append((self.label('MESH', mesh_id),
+                          self.label('MESH', replacement_id),
+                          {'type': 'replaced_by'}))
         self.add_edges_from(edges)
 
     def add_biomappings(self):
@@ -406,6 +471,16 @@ class BioOntology(IndraOntology):
                               {'type': 'partof'}))
         self.add_edges_from(edges)
 
+    def add_uniprot_replacements(self):
+        from indra.databases import uniprot_client
+        edges = []
+        for sec_id, prim_ids in uniprot_client.um.uniprot_sec.items():
+            if len(prim_ids) == 1:
+                edges.append((self.label('UP', sec_id),
+                              self.label('UP', prim_ids[0]),
+                              {'type': 'replaced_by'}))
+        self.add_edges_from(edges)
+
     def add_mirbase_nodes(self):
         from indra.databases import mirbase_client
         nodes = []
@@ -477,6 +552,15 @@ class BioOntology(IndraOntology):
                               {'type': 'xref', 'source': 'hms-lincs'}))
         self.add_edges_from(edges)
 
+    def add_pubchem_xrefs(self):
+        from indra.databases import pubchem_client
+        edges = []
+        for pubchem_id, mesh_id in pubchem_client.pubchem_mesh_map.items():
+            edges.append((self.label('PUBCHEM', pubchem_id),
+                          self.label('MESH', mesh_id),
+                          {'type': 'xref', 'source': 'pubchem'}))
+        self.add_edges_from(edges)
+
     def add_drugbank_nodes(self):
         from indra.databases import drugbank_client
         nodes = []
@@ -536,8 +620,8 @@ class BioOntology(IndraOntology):
         super().add_nodes_from(nodes_for_adding, **attr)
 
     def add_edges_from(self, ebunch_to_add, **attr):
-        for source, target, _ in ebunch_to_add:
-            for label in [source, target]:
+        for edge_info in ebunch_to_add:
+            for label in edge_info[:2]:
                 self.assert_valid_node(label)
         super().add_edges_from(ebunch_to_add, **attr)
 
