@@ -2,6 +2,7 @@ import logging
 import networkx
 import functools
 from collections import deque
+from typing import Optional, Tuple
 
 logger = logging.getLogger(__name__)
 
@@ -30,8 +31,8 @@ class IndraOntology(networkx.DiGraph):
     version = None
     name = None
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self._initialized = False
         self.name_to_grounding = {}
         self.transitive_closure = set()
@@ -434,6 +435,30 @@ class IndraOntology(networkx.DiGraph):
         """
         return self.descendants_rel(ns, id, {'xref'})
 
+    @with_initialize
+    def get_replacement(self, ns, id):
+        """Return a replacement for a given entity or None if no replacement.
+
+        A replacement is typically necessary if the given entity is obsolete
+        and has been replaced by another entry.
+
+        Parameters
+        ----------
+        ns : str
+            An entity's name space.
+        id : str
+            An entity's ID.
+
+        Returns
+        -------
+        : tuple
+            A tuple of the form (ns, id) of the replacement entity
+            or None if no replacement.
+        """
+        rep = list(self.child_rel(ns, id, {'replaced_by'}))
+        if rep:
+            return rep[0]
+
     @with_initialize
     def get_name(self, ns, id):
         """Return the standard name of a given entity.
@@ -547,7 +572,7 @@ class IndraOntology(networkx.DiGraph):
         return self._check_path(ns1, id1, ns2, id2, {'is_opposite'})
 
     @with_initialize
-    def get_id_from_name(self, ns, name):
+    def get_id_from_name(self, ns, name) -> Optional[Tuple[str, str]]:
         """Return an entity's ID given its name space and standard name.
 
         Parameters
@@ -559,9 +584,10 @@ class IndraOntology(networkx.DiGraph):
 
         Returns
         -------
-        str
-            The ID corresponding to the given standard name in
-            the given name space or None if it's not available.
+        :
+            The pair of namespace and ID corresponding to the given
+            standard name in the given name space or None if it's not
+            available.
         """
         if not self.name_to_grounding:
             self._build_name_lookup()
