@@ -5,14 +5,17 @@ import pandas
 import logging
 import requests
 from zipfile import ZipFile
-from collections import defaultdict
+from collections import defaultdict, Counter
 from urllib.request import urlretrieve
 from xml.etree import ElementTree as ET
 from indra.util import read_unicode_csv, write_unicode_csv
-from indra.databases.obo_client import OboClient
+from indra.databases.identifiers import ensure_prefix_if_needed
+from indra.statements.validate import assert_valid_db_refs
+from indra.databases.obo_client import OboClient, PyOboClient
 from indra.databases.owl_client import OwlClient
 from indra.databases import chebi_client, pubchem_client
 from indra.databases.lincs_client import load_lincs_csv
+from indra.ontology.bio import bio_ontology
 from . import load_resource_json, get_resource_path
 
 path = os.path.dirname(__file__)
@@ -50,10 +53,13 @@ def update_hgnc_entries():
     logger.info('--Updating HGNC entries-----')
 
     # Select relevant columns and parameters
-    cols = ['gd_hgnc_id', 'gd_app_sym', 'gd_app_name', 'gd_status',
-            'gd_aliases', 'md_eg_id', 'md_prot_id',
-            'md_mgd_id', 'md_rgd_id', 'gd_prev_sym', 'gd_pub_ensembl_id',
-            'gd_locus_type']
+    cols = [
+        'gd_hgnc_id', 'gd_app_sym', 'gd_app_name', 'gd_status',
+        'gd_aliases', 'md_eg_id', 'md_prot_id',
+        'md_mgd_id', 'md_rgd_id', 'gd_prev_sym', 'gd_pub_ensembl_id',
+        'gd_locus_type',
+        'gd_enz_ids',
+    ]
 
     statuses = ['Approved', 'Entry%20Withdrawn']
     params = {
@@ -285,9 +291,15 @@ def update_chebi_accessions():
                        inplace=True)
     # Here we need to map to primary ChEBI IDs
     from indra.databases.chebi_client import get_primary_id
-    df_cas.COMPOUND_ID.replace(get_primary_id, inplace=True)
+    # This is a wrapper just to strip off the CHEBI prefix to
+    # keep the existing convetions
+    def _get_primary_id_wrapper(chebi_id):
+        return get_primary_id(chebi_id)[6:]
+    df_cas.COMPOUND_ID = df_cas.COMPOUND_ID.apply(_get_primary_id_wrapper)
     df_cas.drop_duplicates(subset=['ACCESSION_NUMBER', 'COMPOUND_ID'],
                            inplace=True)
+    # Temporary fix, see https://github.com/ebi-chebi/ChEBI/issues/4149
+    df_cas = df_cas[~df_cas['ACCESSION_NUMBER'].str.contains('/')]
     df_cas.to_csv(fname, sep='\t',
                   columns=['ACCESSION_NUMBER', 'COMPOUND_ID'],
                   header=['CAS', 'CHEBI'], index=False)
@@ -359,6 +371,88 @@ def update_bel_chebi_map():
                       (chebi_name, chebi_id)).encode('utf-8'))
 
 
+def update_selventa_entries():
+    fname = os.path.join(path, 'selventa_entries.tsv')
+
+    xref_mappings = {
+        'CHEBI': 'CHEBI',
+        'MESHC': 'MESH',
+        'MESHD': 'MESH',
+        'MESHPP': 'MESH',
+        'GOBP': 'GO',
+        'GOCC': 'GO',
+        'DO': 'DOID',
+        }
+
+    def process_selventa_xref(xref):
+        if pandas.isna(xref):
+            return ''
+        db_refs = {}
+        for xref_part in xref.split('|'):
+            prefix, db_id = xref_part.split(':', maxsplit=1)
+            ns = xref_mappings.get(prefix)
+            if not ns:
+                logger.info('Unknown namespace: %s' % prefix)
+                continue
+            db_id = ensure_prefix_if_needed(ns, db_id)
+            db_refs[ns] = db_id
+        assert_valid_db_refs(db_refs)
+        db_refs_str = '|'.join(['%s:%s' % (k, v)
+                                for k, v in sorted(db_refs.items())])
+        return db_refs_str
+
+    resources = {
+        'SCHEM': 'selventa-legacy-chemical-names',
+        'SDIS': 'selventa-legacy-diseases',
+        'SCOMP': 'selventa-named-complexes',
+        'SFAM': 'selventa-protein-families'
+    }
+    base_url = ('https://raw.githubusercontent.com/OpenBEL/resource-generator'
+                '/master/datasets/')
+    rows = []
+    for ns, resource in resources.items():
+        url = base_url + resource + '.txt'
+        df = pandas.read_csv(url, sep='\t', comment='#')
+        for _, df_row in df.iterrows():
+            row = [ns, df_row['ID'], df_row['LABEL'],
+                   process_selventa_xref(df_row['XREF'])]
+            rows.append(row)
+    write_unicode_csv(fname, sorted(rows))
+
+
+def update_pubchem_mesh_map():
+    url = 'https://ftp.ncbi.nlm.nih.gov/pubchem/Compound/Extras/CID-MeSH'
+    res = requests.get(url)
+
+    # We first get mapping pairs from the table
+    mappings = []
+    for line in res.text.split('\n'):
+        parts = line.split('\t')
+        for part in parts[1:]:
+            mappings.append((parts[0], part))
+    # The table has (1) rows with multiple MeSH terms separated by tabs,
+    # (2) multiple rows with the same PubChem CID and (3) multiple rows
+    # with the same MeSH term. We retain only one-to-one mappings here.
+    pc_count = Counter([m[0] for m in mappings])
+    mesh_count = Counter([m[1] for m in mappings])
+    unique_mappings = [m for m in mappings if pc_count[m[0]] == 1
+                       and mesh_count[m[1]] == 1]
+
+    # The mappings table is given using MeSH term names so we need
+    # to convert these to IDs. Lookups can fail for several reasons:
+    # some entries are simply not valid MeSH names, others are not
+    # yet included in the INDRA MeSH resources/ontology.
+    unique_with_id = []
+    for pcid, meshname in unique_mappings:
+        mesh_ns_id_tuple = bio_ontology.get_id_from_name('MESH', meshname)
+        if mesh_ns_id_tuple:
+            unique_with_id.append((pcid, mesh_ns_id_tuple[1]))
+
+    fname = os.path.join(path, 'pubchem_mesh_map.tsv')
+    logger.info('Saving into %s' % fname)
+    write_unicode_csv(fname, unique_with_id, delimiter='\t')
+
+
 def update_famplex_map():
     logger.info('--Updating FamPlex map----')
     # Currently this is a trivial "copy" of the FamPlex equivalences.csv
@@ -547,6 +641,7 @@ def update_mesh_supplementary_names():
         logging.info('Parsing MeSH supplement')
         supp_et = ET.parse(supp_file)
     supp_rows = []
+    reg_number_mappings = []
     for record in supp_et.iterfind('SupplementalRecord'):
         uid = record.find('SupplementalRecordUI').text
         name = record.find('SupplementalRecordName/String').text
@@ -555,10 +650,18 @@ def update_mesh_supplementary_names():
         mapped_to = ','.join([term.text.replace('*', '')
                               for term in mapped_to_terms])
         term_name_str = _get_term_name_str(record, name)
+        reg_number_tags = record.findall('ConceptList/Concept/RegistryNumber')
+        if len(reg_number_tags) == 1:
+            reg_number = reg_number_tags[0].text
+            from indra.statements import validate
+            if validate.validate_id('CAS', reg_number):
+                reg_number_mappings.append([uid, reg_number])
         supp_rows.append((uid, name, term_name_str, mapped_to))
 
     fname = os.path.join(path, 'mesh_supp_id_label_mappings.tsv')
     write_unicode_csv(fname, supp_rows, delimiter='\t')
+    fname = os.path.join(path, 'mesh_cas_mappings.tsv')
+    write_unicode_csv(fname, reg_number_mappings, delimiter='\t')
 
 
 def _get_term_name_str(record, name):
@@ -649,6 +752,11 @@ def update_chebi_obo():
     OboClient.update_resource(path, url, 'chebi', remove_prefix=False)
 
 
+def update_mondo():
+    """Update the Monarch disease ontology (MONDO)."""
+    OboClient.update_from_obo_library('mondo', remove_prefix=True)
+
+
 def update_ido():
     """Update infectious disease ontology (IDO)."""
     OwlClient.update_from_obo_library('ido', remove_prefix=True)
@@ -696,6 +804,18 @@ def update_identifiers_registry():
         json.dump(patterns, fh, indent=1)
 
 
+def update_bioregistry():
+    url = 'https://raw.githubusercontent.com/biopragmatics/bioregistry/main/' \
+        'exports/registry/registry.json'
+    res = requests.get(url)
+    entries = {}
+    keys = ['pattern', 'banana', 'banana_peel', 'synonyms']
+    for prefix, data in res.json().items():
+        entries[prefix] = {k: data[k] for k in keys if k in data}
+    with open(os.path.join(path, 'bioregistry.json'), 'w') as fh:
+        json.dump(entries, fh, indent=1)
+
+
 def update_biomappings():
     """Update mappings from the BioMappings project."""
     from indra.databases import mesh_client
@@ -706,7 +826,7 @@ def update_biomappings():
     biomappings = defaultdict(list)
     mappings = load_mappings()
     predictions = load_predictions()
-    exclude_ns = {'kegg.pathway'}
+    exclude_ns = {'kegg.pathway', 'depmap', 'ccle', 'reactome'}
     for mappings, mapping_type in ((mappings, 'curated'),
                                    (predictions, 'predicted')):
         for mapping in mappings:
@@ -722,6 +842,24 @@ def update_biomappings():
                     (mapping['source prefix'] == 'ncit' or
                      mapping['target prefix'] == 'ncit'):
                 continue
+            # We accept predicted mappings under the following conditions:
+            # MESH-CHEBI If the names match except for capitalization conventions
+            # that are systematically different between MESH and CHEBI.
+            # MESH-UP/HGNC accepted since these are reliable mappings and
+            # are only applied in one direction (from MESH) and can be accepted
+            # even without manual review.
+            # Or any other case in which the standard names match exactly.
+            if mapping_type == 'predicted':
+                if ({mapping['source prefix'],
+                    mapping['target prefix']} == {'chebi', 'mesh'}) and \
+                        (mapping['source name'].lower() !=
+                         mapping['target name'].lower()):
+                    continue
+                elif mapping['source name'] != mapping['target name']:
+                    if not (mapping['source prefix'] == 'mesh' and
+                            mapping['target prefix'] in {'hgnc', 'uniprot'}):
+                        continue
+
             source_ns, source_id = \
                 get_ns_id_from_identifiers(mapping['source prefix'],
                                            mapping['source identifier'])
@@ -736,7 +874,13 @@ def update_biomappings():
             biomappings[(target_ns, target_id, mapping['target name'])].append(
                 (source_ns, source_id, mapping['source name']))
 
-    mesh_mappings = {k: v for k, v in biomappings.items()
+    def _filter_ncit(values):
+        if len(values) > 1 and 'NCIT' in {v[0] for v in values}:
+            return [v for v in values if v[0] != 'NCIT']
+        else:
+            return values
+
+    mesh_mappings = {k: _filter_ncit(v) for k, v in biomappings.items()
                      if k[0] == 'MESH'}
     non_mesh_mappings = {k: [vv for vv in v if vv[0] != 'MESH']
                          for k, v in biomappings.items()
@@ -766,10 +910,18 @@ def update_biomappings():
                 if not mesh_name:
                     continue
                 key = ('MESH', mesh_id, mesh_name)
-                if key not in mesh_mappings:
-                    mesh_mappings[key] = [(db, db_id, entry['name'])]
+                if db_id.startswith('BFO'):
+                    db_to_use = 'BFO'
+                    db_id_to_use = db_id[4:]
                 else:
-                    mesh_mappings[key].append((db, db_id, entry['name']))
+                    db_to_use = db
+                    db_id_to_use = db_id
+                if key not in mesh_mappings:
+                    mesh_mappings[key] = [(db_to_use, db_id_to_use,
+                                           entry['name'])]
+                else:
+                    mesh_mappings[key].append((db_to_use, db_id_to_use,
+                                               entry['name']))
 
     rows = []
     for k, v in mesh_mappings.items():
@@ -814,6 +966,11 @@ def update_lspci():
     write_unicode_csv(get_resource_path('lspci.tsv'), rows, delimiter='\t')
 
 
+def update_ec_code():
+    """Update the EC Code resource."""
+    PyOboClient.update_by_prefix("ec-code", indra_prefix='eccode')
+
+
 def main():
     update_famplex()
     update_famplex_map()
@@ -826,6 +983,7 @@ def main():
     update_chebi_accessions()
     update_hmdb_chebi_map()
     update_bel_chebi_map()
+    update_selventa_entries()
     update_ncit_map()
     update_lincs_small_molecules()
     update_lincs_proteins()
@@ -837,9 +995,12 @@ def main():
     update_efo()
     update_hpo()
     update_ido()
+    update_mondo()
     update_drugbank_mappings()
     update_identifiers_registry()
     update_lspci()
+    update_pubchem_mesh_map()
+    update_ec_code()
 
 
 if __name__ == '__main__':
