@@ -1,3 +1,4 @@
 from .api import process_large_corpus, process_small_corpus, \
     process_belscript, process_pybel_graph, process_json_file, \
-    process_pybel_neighborhood, process_cbn_jgif_file
+    process_pybel_neighborhood, process_cbn_jgif_file, \
+    process_bel_stmt
