@@ -4,18 +4,28 @@ raise custom exceptions derived from ValueError if an invalidity is
 found. These come with a helpful error message that can be caught
 and printed to learn about the specific issue. Another set of functions
 do not raise exceptions, rather, return True or False depending on whether
-the given input is valid or invalid."""
+the given input is valid or invalid.
+
+For validating namespaces and identifiers, there are two validators available,
+one that uses data from identifiers.org and another for Bioregistry.
+"""
 
 import re
 import logging
 from indra.statements import *
-from indra.databases.identifiers import identifiers_mappings, \
-    non_grounding, non_registry, identifiers_registry
+from indra.databases import bioregistry_client, identifiers
 
 
 logger = logging.getLogger(__name__)
 
 
+# These are namespaces that can appear in db_refs but are actually not
+# representing grounding.
+non_grounding = {
+    'TEXT', 'TEXT_NORM'
+}
+
+
 text_ref_patterns = {
     'PMID': re.compile(r'(\d+)'),
     'PMCID': re.compile(r'PMC(\d+)'),
@@ -42,7 +52,8 @@ class InvalidIdentifier(ValueError):
     """Raised when the identifier doesn't match the pattern."""
 
     def __str__(self):
-        return f'Invalid identifier: {self.args[1]} for {self.args[0]} pattern {self.args[2]}'
+        return f'Invalid identifier: {self.args[1]} for {self.args[0]} ' \
+            f'pattern {self.args[2]}'
 
 
 class UnknownIdentifier(ValueError):
@@ -70,7 +81,74 @@ class InvalidStatement(ValueError):
     pass
 
 
-def validate_ns(db_ns):
+class IdentifiersValidator:
+    """A class that can be used to validate INDRA Statements."""
+
+    @staticmethod
+    def assert_valid_ns(db_ns):
+        if db_ns in non_grounding or db_ns in identifiers.non_registry:
+            return
+        identifiers_ns = \
+            identifiers.identifiers_mappings.get(db_ns, db_ns.lower())
+        if identifiers_ns in identifiers.identifiers_registry:
+            return
+        raise UnknownNamespace(db_ns)
+
+    @staticmethod
+    def assert_valid_id(db_ns, db_id):
+        if db_id is None:
+            raise MissingIdentifier(db_ns, None)
+        if db_ns in non_grounding or db_ns in identifiers.non_registry:
+            return
+        identifiers_ns = \
+            identifiers.identifiers_mappings.get(db_ns, db_ns.lower())
+        if identifiers_ns in identifiers.identifiers_registry:
+            pattern = identifiers.identifiers_registry[
+                identifiers_ns]['pattern_compiled']
+            if pattern.match(db_id):
+                return
+            else:
+                raise InvalidIdentifier(db_ns, db_id, pattern.pattern)
+        else:
+            raise UnknownIdentifier(db_ns, db_id)
+
+
+class BioregistryValidator:
+    """A class that can be used to validate INDRA Statements."""
+
+    @staticmethod
+    def assert_valid_ns(db_ns):
+        if db_ns in non_grounding:
+            return
+        prefix = bioregistry_client.bioregistry_overrides.get(db_ns,
+                                                              db_ns.lower())
+        if prefix in bioregistry_client.registry:
+            return
+        raise UnknownNamespace(db_ns)
+
+    @staticmethod
+    def assert_valid_id(db_ns, db_id):
+        if db_id is None:
+            raise MissingIdentifier(db_ns, None)
+        if db_ns in non_grounding:
+            return
+        prefix = bioregistry_client.bioregistry_overrides.get(db_ns,
+                                                              db_ns.lower())
+        if prefix in bioregistry_client.registry:
+            pattern = bioregistry_client.registry[prefix].get(
+                'pattern_compiled')
+            if not pattern or pattern.match(db_id):
+                return
+            else:
+                raise InvalidIdentifier(db_ns, db_id, pattern.pattern)
+        else:
+            raise UnknownIdentifier(db_ns, db_id)
+
+
+default_validator = IdentifiersValidator()
+
+
+def validate_ns(db_ns, validator=default_validator):
     """Return True if the given namespace is known.
 
     Parameters
@@ -84,13 +162,13 @@ def validate_ns(db_ns):
         True if the given namepsace is known, otherwise False.
     """
     try:
-        assert_valid_ns(db_ns)
+        assert_valid_ns(db_ns, validator=validator)
         return True
     except ValueError:
         return False
 
 
-def assert_valid_ns(db_ns):
+def assert_valid_ns(db_ns, validator=default_validator):
     """Raise UnknownNamespace error if the given namespace is unknown.
 
     Parameters
@@ -98,14 +176,10 @@ def assert_valid_ns(db_ns):
     db_ns : str
         The namespace.
     """
-    identifiers_ns = identifiers_mappings.get(db_ns, db_ns.lower())
-    if identifiers_ns in identifiers_registry or db_ns in non_registry \
-            or db_ns in non_grounding:
-        return
-    raise UnknownNamespace(db_ns)
+    return validator.assert_valid_ns(db_ns)
 
 
-def validate_id(db_ns, db_id):
+def validate_id(db_ns, db_id, validator=default_validator):
     """Return True if the given ID is valid in the given namespace.
 
     Parameters
@@ -121,13 +195,13 @@ def validate_id(db_ns, db_id):
         True if the given ID is valid in the given namespace.
     """
     try:
-        assert_valid_id(db_ns, db_id)
+        assert_valid_id(db_ns, db_id, validator=validator)
         return True
     except ValueError:
         return False
 
 
-def assert_valid_id(db_ns, db_id):
+def assert_valid_id(db_ns, db_id, validator=default_validator):
     """Raise InvalidIdentifier error if the ID is invalid in the given
     namespace.
 
@@ -138,22 +212,10 @@ def assert_valid_id(db_ns, db_id):
     db_id : str
         The ID.
     """
-    if db_id is None:
-        raise MissingIdentifier(db_ns, None)
-    identifiers_ns = identifiers_mappings.get(db_ns, db_ns.lower())
-    if identifiers_ns in identifiers_registry:
-        pattern = identifiers_registry[identifiers_ns]['pattern']
-        if re.match(pattern, db_id):
-            return
-        else:
-            raise InvalidIdentifier(db_ns, db_id, pattern)
-    elif db_ns in non_registry or db_ns in non_grounding:
-        return
-    else:
-        raise UnknownIdentifier(db_ns, db_id)
+    return validator.assert_valid_id(db_ns, db_id)
 
 
-def validate_db_refs(db_refs):
+def validate_db_refs(db_refs, validator=default_validator):
     """Return True if all the entries in the given db_refs are valid.
 
     Parameters
@@ -167,13 +229,13 @@ def validate_db_refs(db_refs):
         True if all the entries are valid, else False.
     """
     try:
-        assert_valid_db_refs(db_refs)
+        assert_valid_db_refs(db_refs, validator=validator)
         return True
     except ValueError:
         return False
 
 
-def assert_valid_db_refs(db_refs):
+def assert_valid_db_refs(db_refs, validator=default_validator):
     """Raise InvalidIdentifier error if any of the entries in the given
     db_refs are invalid.
 
@@ -183,11 +245,11 @@ def assert_valid_db_refs(db_refs):
         A dict of database references, typically part of an INDRA Agent.
     """
     for db_ns, db_id in db_refs.items():
-        assert_valid_ns(db_ns)
-        assert_valid_id(db_ns, db_id)
+        assert_valid_ns(db_ns, validator=validator)
+        assert_valid_id(db_ns, db_id, validator=validator)
 
 
-def assert_valid_agent(agent):
+def assert_valid_agent(agent, validator=default_validator):
     """Raise InvalidAgent is there is an invalidity in the Agent.
 
     Parameters
@@ -199,10 +261,10 @@ def assert_valid_agent(agent):
         return
     if agent.name is None:
         raise InvalidAgent('Agent missing name')
-    assert_valid_db_refs(agent.db_refs)
+    assert_valid_db_refs(agent.db_refs, validator=validator)
 
 
-def validate_agent(agent):
+def validate_agent(agent, validator=default_validator):
     """Return False if is there is an invalidity in the Agent, otherwise True.
 
     Parameters
@@ -216,7 +278,7 @@ def validate_agent(agent):
         True if the agent is valid, False otherwise.
     """
     try:
-        assert_valid_agent(agent)
+        assert_valid_agent(agent, validator=validator)
         return True
     except ValueError:
         return False
@@ -260,7 +322,7 @@ def assert_valid_statement_semantics(stmt):
             raise InvalidStatement('Translocation with no locations.')
 
 
-def validate_statement(stmt):
+def validate_statement(stmt, validator=default_validator):
     """Return True if all the groundings in the given statement are valid.
 
     Parameters
@@ -275,14 +337,14 @@ def validate_statement(stmt):
         Statement are valid, else False.
     """
     try:
-        assert_valid_statement(stmt)
+        assert_valid_statement(stmt, validator=validator)
         return True
     # Some deeper validation checks in statements raise TypeErrors
     except (ValueError, TypeError):
         return False
 
 
-def assert_valid_statement(stmt):
+def assert_valid_statement(stmt, validator=default_validator):
     """Raise an error if there is anything invalid in the given statement.
 
     Parameters
@@ -292,12 +354,12 @@ def assert_valid_statement(stmt):
     """
     assert_valid_statement_semantics(stmt)
     for agent in stmt.real_agent_list():
-        assert_valid_agent(agent)
+        assert_valid_agent(agent, validator=validator)
     for ev in stmt.evidence:
-        assert_valid_evidence(ev)
+        assert_valid_evidence(ev, validator=validator)
 
 
-def assert_valid_statements(stmts):
+def assert_valid_statements(stmts, validator=default_validator):
     """Raise an error of any of the given statements is invalid.
 
     Parameters
@@ -306,10 +368,10 @@ def assert_valid_statements(stmts):
         A list of INDRA Statements to validate.
     """
     for stmt in stmts:
-        assert_valid_statement(stmt)
+        assert_valid_statement(stmt, validator=validator)
 
 
-def print_validation_report(stmts):
+def print_validation_report(stmts, validator=default_validator):
     """Log the first validation error encountered for each given statement.
 
     Parameters
@@ -319,7 +381,7 @@ def print_validation_report(stmts):
     """
     for idx, stmt in enumerate(stmts):
         try:
-            assert_valid_statement(stmt)
+            assert_valid_statement(stmt, validator=validator)
         except Exception as e:
             logger.info(f'{idx}: {type(e).__name__} - {e}')
 
@@ -356,7 +418,7 @@ def assert_valid_pmid_text_refs(evidence):
                                   f'match text refs pmid {tr_pmid}')
 
 
-def assert_valid_bio_context(context):
+def assert_valid_bio_context(context, validator=default_validator):
     """Raise InvalidContext error if the given bio-context is invalid.
 
     Parameters
@@ -374,10 +436,10 @@ def assert_valid_bio_context(context):
             continue
         if val is not None and not isinstance(val, RefContext):
             raise InvalidContext(f'Invalid context entry for {attr}')
-        assert_valid_db_refs(val.db_refs)
+        assert_valid_db_refs(val.db_refs, validator=validator)
 
 
-def assert_valid_context(context):
+def assert_valid_context(context, validator=default_validator):
     """Raise InvalidContext error if the given context is invalid.
 
     Parameters
@@ -388,12 +450,12 @@ def assert_valid_context(context):
     if context is None:
         return
     elif isinstance(context, BioContext):
-        assert_valid_bio_context(context)
+        assert_valid_bio_context(context, validator=validator)
     elif isinstance(context, WorldContext):
         return
 
 
-def assert_valid_evidence(evidence):
+def assert_valid_evidence(evidence, validator=default_validator):
     """Raise an error if the given evidence is invalid.
 
     Parameters
@@ -403,10 +465,10 @@ def assert_valid_evidence(evidence):
     """
     assert_valid_pmid_text_refs(evidence)
     assert_valid_text_refs(evidence.text_refs)
-    assert_valid_context(evidence.context)
+    assert_valid_context(evidence.context, validator=validator)
 
 
-def validate_evidence(evidence):
+def validate_evidence(evidence, validator=default_validator):
     """Return False if the given evidence is invalid, otherwise True.
 
     Parameters
@@ -420,7 +482,7 @@ def validate_evidence(evidence):
         True if the evidence is valid, otherwise False.
     """
     try:
-        assert_valid_evidence(evidence)
+        assert_valid_evidence(evidence, validator=validator)
         return True
     except ValueError:
         return False
