@@ -4,7 +4,7 @@ from indra.statements import *
 from indra.belief import BeliefEngine, load_default_probs, \
     sample_statements, evidence_random_noise_prior, tag_evidence_subtype, \
     SimpleScorer
-from indra.belief import wm_scorer, BayesianScorer
+from indra.belief import BayesianScorer
 
 default_probs = load_default_probs()
 
@@ -148,6 +148,25 @@ def test_default_probs_override():
                 assert default_probs[err_type][k] == v
 
 
+def test_score_statement():
+    """Check that we can correctly score a single statement."""
+    prior_probs = {'rand': {'reach': 0.1, 'trips': 0.2},
+                   'syst': {'reach': 0,   'trips': 0}}
+
+    scorer = SimpleScorer(prior_probs)
+    # ev1 is from "reach"
+    st1 = Phosphorylation(None, Agent('a'), evidence=[ev1])
+    belief = scorer.score_statement(st1)
+    assert belief == 0.9
+    # try extra_evidence empty list:
+    belief = scorer.score_statement(st1, extra_evidence=[])
+    assert belief == 0.9
+    # Now we try extra_evidence from trips.
+    # Expected result is 1 - (0.1 * 0.2) = 0.98
+    belief = scorer.score_statement(st1, extra_evidence=[ev2])
+    assert belief == 0.98
+
+
 def test_default_probs_extend():
     """Make sure default probs are extended by constructor argument."""
     prior_probs = {'rand': {'new_source': 0.1},
@@ -300,17 +319,6 @@ def test_negative_evidence():
     assert stmts[2].belief == 0
 
 
-def test_wm_scorer():
-    scorer = wm_scorer.get_eidos_scorer()
-    stmt = Influence(Concept('a'), Concept('b'),
-                     evidence=[Evidence(source_api='eidos')])
-    # Make sure other sources are still in the map
-    assert 'hume' in scorer.prior_probs['rand']
-    assert 'biopax' in scorer.prior_probs['syst']
-    engine = BeliefEngine(scorer)
-    engine.set_prior_probs([stmt])
-
-
 def test_bayesian_scorer():
     prior_counts = {'hume': [3, 1]}
     subtype_counts = {'eidos': {'rule1': [2, 2], 'rule2': [1, 4]}}
