@@ -3,6 +3,8 @@ from indra.assemblers.pysb import PysbAssembler
 import indra.assemblers.pysb.assembler as pa
 from indra.assemblers.pysb.assembler import Policy, Param
 from indra.assemblers.pysb.preassembler import PysbPreassembler
+from indra.assemblers.pysb.export import export_cm_network
+from indra.assemblers.pysb.kappa_util import get_cm_cycles
 from indra.statements import *
 from pysb import bng, WILD, Monomer, Annotation
 from pysb.testing import with_model
@@ -849,6 +851,29 @@ def test_phospho_assemble_grounding():
         check_policy(policy)
 
 
+def test_get_grounded_agents_from_model():
+    mek = Agent('MEK1', db_refs={'HGNC': '6840'})
+    erk = Agent('ERK2', db_refs={'HGNC': '6871'})
+    erk_phos = Agent('ERK2', db_refs={'HGNC': '6871'},
+                     mods=[ModCondition('phosphorylation')])
+    erk_phos_y187 = Agent('ERK2', db_refs={'HGNC': '6871'},
+                       mods=[ModCondition('phosphorylation', 'Y', '187')])
+    phos_stmt = Phosphorylation(mek, erk)
+    phos_y187_stmt = Phosphorylation(mek, erk, 'Y', '187')
+    pysba = pa.PysbAssembler([phos_stmt, phos_y187_stmt])
+    pysb_model = pysba.make_model()
+    agents_by_mp, mps_by_rule = pa.get_grounded_agents(pysb_model)
+    assert isinstance(agents_by_mp, dict)
+    assert isinstance(mps_by_rule, dict)
+    model_agents = agents_by_mp.values()
+    model_keys = set([ag.matches_key() for ag in model_agents])
+    # TODO add other types of agent conditions here
+    # TODO do we expect a different agent for af?
+    test_keys = set([mek.matches_key(), erk_phos.matches_key(),
+                     erk_phos_y187.matches_key()])
+    assert len(model_keys.intersection(test_keys)) == 3
+
+
 def test_phospho_mod_grounding():
     a = Agent('MEK1', mods=[ModCondition('phosphorylation', 'S', '218'),
                             ModCondition('phosphorylation', 'S', '222')],
@@ -1235,3 +1260,36 @@ def test_kappa_cm_export():
     graph = pa.export_model('kappa_cm', '/dev/null')
     assert len(graph.nodes()) == 2
     assert len(graph.edges()) == 1
+
+
+def test_contact_map_cycles_1():
+    stmts = [Complex([Agent('a'), Agent('b')]),
+             Complex([Agent('a'), Agent('c')]),
+             Complex([Agent('b'), Agent('c')])]
+    pa = PysbAssembler(stmts)
+    pa.make_model()
+    graph = export_cm_network(pa.model)
+    assert len(graph.nodes()) == 9, len(graph.nodes)
+    assert len(graph.edges()) == 9, len(graph.edges)
+
+    cycles = get_cm_cycles(graph)
+    assert len(cycles) == 1, cycles
+    assert cycles[0] == ['a(b)', 'b(a)', 'b(c)', 'c(b)', 'c(a)', 'a(c)']
+
+
+def test_contact_map_cycles_2():
+    erk1 = Agent('MAPK1', db_refs={'HGNC': '6871'})
+    erk2 = Agent('MAPK3', db_refs={'HGNC': '6877'})
+    # In this case there will be no cycles because the binding site on x
+    # for ERK1 and ERK2 is generated to be competitive.
+    stmts = [Complex([Agent('x'), erk1]),
+             Complex([Agent('x'), erk2]),
+             Complex([erk1, erk2])]
+    pa = PysbAssembler(stmts)
+    pa.make_model()
+    graph = export_cm_network(pa.model)
+    assert len(graph.nodes()) == 8, len(graph.nodes)
+    assert len(graph.edges()) == 8, len(graph.edges)
+
+    cycles = get_cm_cycles(graph)
+    assert not cycles, cycles
