@@ -312,17 +312,6 @@ def test_run_preassembly_concepts():
     assert len(st_out) == 2, st_out
 
 
-def test_preassembly_wm_scorer():
-    route = 'preassembly/run_preassembly'
-    ev = Evidence(source_api='eidos',
-                  annotations={'found_by': 'dueToSyntax2-Causal'})
-    st = Influence(Event(Concept('x')), Event(Concept('y')), evidence=[ev])
-    stmts_json = stmts_to_json([st])
-    st_out = _post_stmts_preassembly([st], route, belief_scorer='wm')
-    stmt = st_out[0]
-    assert stmt.belief == 0.8142, stmt.belief
-
-
 def test_expand_families():
     route = 'preassembly/expand_families'
     st_out = _post_stmts_preassembly([st10], route)
@@ -704,58 +693,6 @@ def test_merge_groundings():
     assert stmts[0].obj.concept.db_refs == stmts[0].subj.concept.db_refs
 
 
-def test_merge_deltas():
-    def add_annots(stmt):
-        for ev in stmt.evidence:
-            ev.annotations['subj_adjectives'] = stmt.subj.delta.adjectives
-            ev.annotations['obj_adjectives'] = stmt.obj.delta.adjectives
-            ev.annotations['subj_polarity'] = stmt.subj.delta.polarity
-            ev.annotations['obj_polarity'] = stmt.obj.delta.polarity
-        return stmt
-
-    d1 = QualitativeDelta(polarity=1, adjectives=['a', 'b', 'c'])
-    d2 = QualitativeDelta(polarity=-1, adjectives=None)
-    d3 = QualitativeDelta(polarity=1, adjectives=['g'])
-    d4 = QualitativeDelta(polarity=-1, adjectives=['d', 'e', 'f'])
-    d5 = QualitativeDelta(polarity=None, adjectives=['d'])
-    d6 = QualitativeDelta(polarity=None, adjectives=None)
-    d7 = QualitativeDelta(polarity=1, adjectives=None)
-
-    def make_ev(name, delta):
-        return Event(Concept(name), delta=delta)
-
-    route_preassembly = 'preassembly/run_preassembly'
-    route_deltas = 'preassembly/merge_deltas'
-
-    stmts = [add_annots(Influence(make_ev('a', sd), make_ev('b', od),
-                                  evidence=[Evidence(source_api='eidos',
-                                                     text='%d' % idx)]))
-             for idx, (sd, od) in enumerate([(d1, d2), (d3, d4)])]
-    stmts = _post_stmts_preassembly(
-        stmts, route_preassembly, return_toplevel=True)
-    stmts = _post_stmts_preassembly(stmts, route_deltas)
-    assert stmts[0].subj.delta.polarity == 1, stmts[0].subj.delta
-    assert stmts[0].obj.delta.polarity == -1, stmts[0].obj.delta
-    assert set(stmts[0].subj.delta.adjectives) == {'a', 'b', 'c', 'g'}, \
-        stmts[0].subj.delta
-    assert set(stmts[0].obj.delta.adjectives) == {'d', 'e', 'f'}, \
-        stmts[0].obj.delta
-
-    stmts = [add_annots(Influence(make_ev('a', sd), make_ev('b', od),
-                                  evidence=[Evidence(source_api='eidos',
-                                                     text='%d' % idx)]))
-             for idx, (sd, od) in enumerate([(d1, d5), (d6, d7), (d6, d7)])]
-    stmts = _post_stmts_preassembly(
-        stmts, route_preassembly, return_toplevel=True)
-    stmts = _post_stmts_preassembly(stmts, route_deltas)
-    assert stmts[0].subj.delta.polarity is None, stmts[0].subj.delta
-    assert stmts[0].obj.delta.polarity == 1, stmts[0].obj.delta
-    assert set(stmts[0].subj.delta.adjectives) == {'a', 'b', 'c'}, \
-        stmts[0].subj.delta
-    assert set(stmts[0].obj.delta.adjectives) == {'d'}, \
-        stmts[0].obj.delta
-
-
 def test_preassemble_flatten():
     route = 'preassembly/run_preassembly'
     st_out = _post_stmts_preassembly(
@@ -924,31 +861,9 @@ def test_reach_process_pmc():
     assert stmts[0].evidence[0].pmid is not None
 
 
-def test_cwms_process_text():
-    res = _call_api('post', '/cwms/process_text',
-                    json={'text': 'Hunger causes displacement.'})
-    res_json = json.loads(res.get_data())
-    stmts_json = res_json.get('statements')
-    stmts = stmts_from_json(stmts_json)
-    assert len(stmts) == 1
-
-
-def test_hume_process_jsonld():
-    from indra.tests.test_hume import test_file_new_simple
-    with open(test_file_new_simple, 'r') as fh:
-        test_jsonld = fh.read()
-    res = _call_api('post', '/hume/process_jsonld',
-                    json={'jsonld': test_jsonld})
-    res_json = json.loads(res.get_data())
-    stmts_json = res_json.get('statements')
-    stmts = stmts_from_json(stmts_json)
-    assert len(stmts) == 1
-
-
 def test_eidos_json():
-    from indra.tests.test_eidos import test_jsonld
-    with open(test_jsonld, 'r') as fh:
-        test_json = fh.read()
+    from indra.tests.test_eidos import _read_eidos_sentence_json
+    test_json = json.dumps(_read_eidos_sentence_json())
     res = _call_api('post', '/eidos/process_jsonld',
                     json={'jsonld': test_json})
     res_json = json.loads(res.get_data())
