@@ -80,7 +80,9 @@ boolean_args = [
     'do_rename', 'use_adeft', 'do_methionine_offset', 'do_orthology_mapping',
     'do_isoform_mapping', 'use_cache', 'return_toplevel', 'flatten_evidence',
     'normalize_equivalences', 'normalize_opposites', 'invert', 'remove_bound',
-    'specific_only', 'allow_families', 'match_suffix', 'update_belief']
+    'specific_only', 'allow_families', 'match_suffix', 'update_belief',
+    'in_place', 'print_report_before', 'print_report_after',
+    'prior_hash_annots']
 list_args = [
     'gene_list', 'name_list', 'values', 'source_apis', 'uuids', 'curations',
     'correct_tags', 'ignores', 'deletions']
@@ -305,7 +307,7 @@ reach_text_model = api.inherit('ReachText', bio_text_model, {
 })
 reach_json_model = api.model('ReachJSON', {'json': fields.String(example='{}')})
 reach_pmc_model = api.model('ReachPMC', {
-    'pmcid': fields.String(example='PMC3717945'),
+    'pmc_id': fields.String(example='PMC8511698'),
     'offline': fields.Boolean(default=False),
     'url': fields.String(example=reach_nxml_url)
 })
@@ -407,7 +409,7 @@ class ReachProcessPmc(Resource):
         pmc_id : str
             The ID of a PubmedCentral article. The string may start with PMC
             but passing just the ID also works.
-            Examples: 3717945, PMC3717945
+            Examples: 8511698, PMC8511698
             https://www.ncbi.nlm.nih.gov/pmc/
 
         offline : Optional[bool]
@@ -428,7 +430,7 @@ class ReachProcessPmc(Resource):
             A list of extracted INDRA Statements.
         """
         args = request.json
-        pmcid = args.get('pmcid')
+        pmcid = args.get('pmc_id')
         offline = True if args.get('offline') else False
         given_url = args.get('url')
         config_url = get_config('REACH_NXML_URL', failure_ok=True)
